/* 
 * delta_stream.h :  defines svn_delta_stream_t  (private to libsvn_delta)
 *
 * ================================================================
 * Copyright (c) 2000 Collab.Net.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * 
 * 3. The end-user documentation included with the redistribution, if
 * any, must include the following acknowlegement: "This product includes
 * software developed by Collab.Net (http://www.Collab.Net/)."
 * Alternately, this acknowlegement may appear in the software itself, if
 * and wherever such third-party acknowlegements normally appear.
 * 
 * 4. The hosted project names must not be used to endorse or promote
 * products derived from this software without prior written
 * permission. For written permission, please contact info@collab.net.
 * 
 * 5. Products derived from this software may not use the "Tigris" name
 * nor may "Tigris" appear in their names without prior written
 * permission of Collab.Net.
 * 
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL COLLAB.NET OR ITS CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
 * IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * ====================================================================
 * 
 * This software may consist of voluntary contributions made by many
 * individuals on behalf of Collab.Net.
 */



#ifndef SVN_DELTA_STREAM_H
#define SVN_DELTA_STREAM_H

#include "svn_delta.h"



/* This implementation is only for testing the interface. */
struct svn_delta_stream_t {
  /* These are copied from parameters passed to make_delta_stream. */
  svn_delta_read_fn_t* source_fn;
  void* source_data;
  svn_delta_read_fn_t* target_fn;
  void* target_data;

  /* Private data */
  apr_pool_t* pool;
  svn_boolean_t more;
};



/* Allocate and initalize a delta window.. */
extern svn_error_t* svn_tdelta__init_window (svn_delta_window_t** window,
                                             svn_delta_stream_t* stream);

/* Insert a delta op into the delta window. If the opcode is
   svn_delta_new, bytes from new_data are copied into the window
   data and offset is ignored, as it's maintained in the winfo struct.
   Otherwise new_data is ignored and may be NULL. */
extern svn_error_t* svn_tdelta__insert_op (svn_delta_window_t* window,
                                           int opcode,
                                           apr_off_t offset,
                                           apr_off_t length,
                                           char const* new_data);

/* Create a vdelta */
extern svn_error_t* svn_tdelta__vdelta (svn_delta_window_t** window,
                                        svn_delta_stream_t* stream);

/* Window size; we might or might not need that. */
extern size_t svn_tdelta__window_size;


#endif /* SVN_DELTA_STREAM_H */



/* 
 * local variables:
 * eval: (load-file "../svn-dev.el")
 * end:
 */
